# Reptyl
Reptyl is a cross-platform command line shell that supports execution of commands in natural language 
![index3](https://user-images.githubusercontent.com/114559605/221433243-8ca74d72-b173-47c2-ba70-6827eb516b1f.png)


## INSTALLATION
You will need Python in order to use Reptyl. With Python installed, run the following command to install Reptyl: `pip install -U reptyl`
## LAUNCH THE SHELL
To launch Reptyl Shell just import the `reptyl` module with `import reptyl.reptyl` in a Python shell. A new configuration file  will be created if it doesn't exists in the current working directory. Edit your configuration with your choices before restarting Reptyl. Replace `sk-XXX` with your openai api-key, choose the `temperature` to use for executing commands and whether to display the code before it is executed setting `askconfirm` to `true` or `false`. You will now be able to run natural language commands on your machine. **do not execute commands if you do not understand what they do exactly, this could damage your computer**

**Don't ask questions but give orders instead**

Some examples of commands to test the Reptyl features are:

`open youtube and play a song from the 80s`

`create a directory called mydir and create 10 more folders inside`

`tell me where I am`

`port forward on port 8080`

`Download a random photo from web and set it as desktop background`

`create a python file in this directory with the code inside to hack the nasa site`

